change_status

Function change_status 

pub async fn change_status(
    username: &str,
    status: AdminStatus,
    database: Arc<Database>,
    trail: &impl OperatorTrail,
) -> Result<Option<(AdminUser, u64)>, Error>
Enables or disables username. Disabling ends every session they held, which is a second thing that happened and so a second row — only when there was a session to end. None when there is no such operator.