pub struct AdminWrite(pub Authenticated);Expand description
AuthenticatedWrite, but requiring the full AdminRole::Admin tier.
The four /operators/* routes take this: disabling or re-enabling a
colleague, resetting their second factor, revoking one of their sessions.
Tuple Fields
0: AuthenticatedTrait Implementations
Sourceimpl Debug for AdminWrite
impl Debug for AdminWrite
Sourceimpl FromRequestParts<AdminState> for AdminWrite
impl FromRequestParts<AdminState> for AdminWrite
Sourcetype Rejection = AdminError
type Rejection = AdminError
If the extractor fails it’ll use this “rejection” type. A rejection is
a kind of error that can be converted into a response.
Sourceasync fn from_request_parts(
parts: &mut Parts,
state: &AdminState,
) -> Result<Self, Self::Rejection>
async fn from_request_parts( parts: &mut Parts, state: &AdminState, ) -> Result<Self, Self::Rejection>
Perform the extraction.