pub struct Authenticated {
pub session: AdminSession,
pub user: AdminUser,
}Expand description
A live session and the operator it belongs to. Read-only handlers take this.
Fields
session: AdminSessionuser: AdminUserTrait Implementations
Sourceimpl Debug for Authenticated
impl Debug for Authenticated
Sourceimpl FromRequestParts<AdminState> for Authenticated
impl FromRequestParts<AdminState> for Authenticated
Sourcetype Rejection = AdminError
type Rejection = AdminError
If the extractor fails it’ll use this “rejection” type. A rejection is
a kind of error that can be converted into a response.
Sourceasync fn from_request_parts(
parts: &mut Parts,
state: &AdminState,
) -> Result<Self, Self::Rejection>
async fn from_request_parts( parts: &mut Parts, state: &AdminState, ) -> Result<Self, Self::Rejection>
Perform the extraction.